<?php

/**
 * Plugin Name: YayMail Addon for Custom Email
 * Plugin URI: https://www.solagirl.net
 * Description: An example of how to make write YayMail extention.
 * Version: 1.0
 * Author: Sola
 * Author URI: https://www.solagirl.net
 * Text Domain: yaymail
 * WC requires at least: 3.0.0
 * WC tested up to: 6.0.2
 * Domain Path: /i18n/languages/
 */

namespace YayMailCustomEmail;

defined('ABSPATH') || exit;

spl_autoload_register(
	function ($class) {
		$prefix   = __NAMESPACE__;
		$base_dir = __DIR__ . '/views';

		$len = strlen($prefix);
		if (strncmp($prefix, $class, $len) !== 0) {
			return;
		}

		$relative_class_name = substr($class, $len);

		$file = $base_dir . str_replace('\\', '/', $relative_class_name) . '.php';

		if (file_exists($file)) {
			require $file;
		}
	}
);

// Add action link customize
add_filter('plugin_action_links_' . plugin_basename(__FILE__),  __NAMESPACE__ . '\\yaymail_addon_add_action_links');
function yaymail_addon_add_action_links($actions) {

	if (defined('YAYMAIL_PREFIX')) {
		$links   = array(
			'<a href="' . admin_url('admin.php?page=yaymail-settings') . '" aria-label="' . esc_attr__('View WooCommerce Email Builder', 'yaymail') . '">' . esc_html__('Start Customizing', 'yaymail') . '</a>',
		);
		$actions = array_merge($links, $actions);
	}
	return $actions;
}

// Add action link docs and support
add_filter('plugin_row_meta', __NAMESPACE__ . '\\yaymail_addon_custom_plugin_row_meta', 10, 2);
function yaymail_addon_custom_plugin_row_meta($plugin_meta, $plugin_file) {

	if (strpos($plugin_file, plugin_basename(__FILE__)) !== false) {
		$new_links = array(
			'docs'    => '<a href="https://yaycommerce.gitbook.io/yaymail/" aria-label="' . esc_attr__('View YayMail documentation', 'yaymail') . '">' . esc_html__('Docs', 'yaymail') . '</a>',
			'support' => '<a href="https://yaycommerce.com/support/" aria-label="' . esc_attr__('Visit community forums', 'yaymail') . '">' . esc_html__('Support', 'yaymail') . '</a>',
		);

		$plugin_meta = array_merge($plugin_meta, $new_links);
	}

	return $plugin_meta;
}

// Add action notice
add_action('after_plugin_row_' . plugin_basename(__FILE__), __NAMESPACE__ . '\\yaymail_addon_add_notification_after_plugin_row', 10, 2);
function yaymail_addon_add_notification_after_plugin_row($plugin_file, $plugin_data) {

	if (!defined('YAYMAIL_PREFIX')) {
		$wp_list_table = _get_list_table('WP_MS_Themes_List_Table');
?>
		<script>
			var plugin_row_element = document.querySelector('tr[data-plugin="<?php echo esc_js(plugin_basename(__FILE__)); ?>"]');
			plugin_row_element.classList.add('update');
		</script>
	<?php
		echo '<tr class="plugin-update-tr' . (is_plugin_active($plugin_file) ? ' active' : '') . '"><td colspan="' . esc_attr($wp_list_table->get_column_count()) . '" class="plugin-update colspanchange" >';
		echo '<div class="notice inline notice-warning notice-alt"><p>';
		echo esc_html__('To use this addon, you need to install and activate YayMail plugin. Get ', 'yaymail') . '<a href="' . esc_url('https://wordpress.org/plugins/yaymail/') . '">' . esc_html__('YayMail Free', 'yaymail') . '</a> or <a href="' . esc_url('https://yaycommerce.com/yaymail-woocommerce-email-customizer/') . '">' . esc_html__('YayMail Pro', 'yaymail') . '</a>.
					</p>
				</div>
			</td>
			</tr>';
	}
}

function yaymail_subscription_dependence() {
	wp_enqueue_script('yaymail-subscription', plugin_dir_url(__FILE__) . 'assets/dist/js/app.js', array(), YAYMAIL_VERSION, true);
	wp_enqueue_style('yaymail-subscription', plugin_dir_url(__FILE__) . 'assets/dist/css/app.css', array(), YAYMAIL_VERSION);
}
//add_action( 'yaymail_before_enqueue_dependence', __NAMESPACE__ . '\\\yaymail_custom_email_dependence' );

// Register your custom email
function yaymail_register_email_template($plugins) {
	$plugins[] = array(
		'plugin_name'      => 'Sola_WC_Custom_Email',
		'addon_components' => array(),
		'template_name'    => array('my_custom_email'),
	);
	return $plugins;
}
add_filter('yaymail_plugins', __NAMESPACE__ . '\\yaymail_register_email_template');

// Action create template default
add_filter('YaymailNewTempalteDefault', __NAMESPACE__ . '\\yaymail_new_template_default', 100, 3);
function yaymail_new_template_default($array, $key, $value) {
	if ('Sola_WC_Custom_Email' == $key) {
		$getHeading                   = $value->get_heading();
		$defaultCustomEmail = templateDefault\DefaultCustomEmail::getTemplates($value->id, $getHeading);
		return $defaultCustomEmail;
	}
	return $array;
}

/** SHORTCODE WILL DO HERE */

// Add shortcode to the list of shortcodes in the block editor
function yaymail_addon_custom_shortcode_attributes($shortcode_list) {
	$shortcode_list[] = array(
		'plugin' => 'Group Name',
		'shortcode' => array(
			['[yaymail_addon_custom_email_info]', 'my shortcode'],
		)
	);
	return $shortcode_list;
}
add_filter('yaymail_list_shortcodes', __NAMESPACE__ . '\\yaymail_addon_custom_shortcode_attributes');

// Call add_shortcode and pass some parameters
function yaymail_addon_add_shortcodes_to_list($shortcode_list) {
	$shortcode_list[] = 'yaymail_addon_custom_email_info';
	return $shortcode_list;
}
add_filter('yaymail_shortcodes', __NAMESPACE__ . '\\yaymail_addon_add_shortcodes_to_list');

// Create the replacement array to map shortcode to its content
function yaymail_addon_shortcode_callback_list($shortcode_list, $yaymail_informations, $args = array()) {
	$shortcode_list['[yaymail_addon_custom_email_info]'] = yaymail_addon_custom_email_info($yaymail_informations, $args);
	return $shortcode_list;
}
add_filter('yaymail_do_shortcode', __NAMESPACE__ . '\\yaymail_addon_shortcode_callback_list', 10, 3);

// Define the output of the custom shortcodes
function yaymail_addon_custom_email_info($yaymail_informations, $args) {
	
	ob_start();
	if (isset($yaymail_informations['order'])) : ?>
		<div>
			<hr>
			<p>Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod
				tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam,
				quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo
				consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse
				cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non
				proident, sunt in culpa qui officia deserunt mollit anim id est laborum.</p>
		</div>
	<?php else : ?>
		<h3>Demo content when sample order is selected</h3>
<?php
	endif;

	return ob_get_clean();
}
